#!/bin/sh

chmod 0555 /opt/sbin/makemap
chmod 0555 /opt/sbin/editmap
chmod 0555 /opt/sbin/mail.local
chmod 0555 /opt/sbin/praliases
chmod 0555 /opt/sbin/mailstats
chmod 0555 /opt/sbin/smrsh
chmod 4555 /opt/sbin/sendmail
chmod 0555 /opt/bin/vacation

chmod 644 /etc/mail/*
chown bin.bin /etc/mail/helpfile
chmod 444 /etc/mail/helpfile
chmod 600 /etc/mail/statistics

test -d /var/spol/mail || mkdir /var/spool/mail
chmod 755 /var/spool/mail
test -d /var/spool/mqueue || mkdir /var/spool/mqueue
chmod 755 /var/spool/mqueue
test -d /var/spool/clientmqueue || mkdir /var/spool/clientmqueue
chmod 755 /var/spool/clientmqueue
